@@ -57,6 +57,9 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
+      it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
@@ -69,10 +72,11 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('log_filters').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -89,6 +93,8 @@ describe 'nova::compute::libvirt' do
           :hw_disk_discard                            => 'unmap',
           :hw_machine_type                            => 'x86_64=machinetype1,armv7l=machinetype2',
           :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
+          :device_detach_attempts                     => 8,
+          :device_detach_timeout                      => 20,
           :libvirt_service_name                       => 'custom_service',
           :virtlock_service_name                      => 'virtlock',
           :virtlog_service_name                       => 'virtlog',
@@ -110,6 +116,7 @@ describe 'nova::compute::libvirt' do
           :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
           :ovs_timeout                                => 10,
           :max_queues                                 => 4,
+          :num_memory_encrypted_guests                => 255,
         }
       end
 
@@ -129,6 +136,8 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value(8)}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value(20)}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
@@ -142,9 +151,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('"1:file:/var/log/libvirt/libvirtd.log"')}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value('"1:qemu"')}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('"NORMAL:-VERS-SSL3.0"')}
+      it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('1:file:/var/log/libvirt/libvirtd.log').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('log_filters').with_value('1:qemu').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('NORMAL:-VERS-SSL3.0').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value(10)}
       it {
         is_expected.to contain_service('libvirt').with(
@@ -270,6 +280,9 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
     end
 
@@ -278,6 +291,8 @@ describe 'nova::compute::libvirt' do
         { :virt_type                                  => 'qemu',
           :vncserver_listen                           => '0.0.0.0',
           :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
+          :device_detach_attempts                     => 8,
+          :device_detach_timeout                      => 20,
           :nfs_mount_options                          => 'rw,intr,nolock',
           :mem_stats_period_seconds                   => 20,
         }
@@ -286,6 +301,8 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value(8)}
+      it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value(20)}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
       it { is_expected.to contain_package('libvirt').with(
